import json
from typing import Dict, Any

from .getcookie import CookieManager


def get_config():
    """输入用户名和密码修改config.json"""
    DEFAULT_CONFIG: Dict[str, Any] = {
        "max_workers": 10,
        "max_retries": 3,
        "DEFAULT_CONNECT_TIMEOUT": 3,
        "DEFAULT_READ_TIMEOUT": 5,
        "DEFAULT_RETRY_DELAY": 5,
        "DEFAULT_BATCH_SIZE": 6
    }

    import os
    from dotenv import load_dotenv
    load_dotenv()
    name=os.getenv("name")
    password=os.getenv("password")
    tel=os.getenv("tel")
    base_url=os.getenv("base_url")

    from getcrpit import encrypt
    payload = {"username": name, "password": password, "phoneNumber": tel}
    plain = json.dumps(payload, ensure_ascii=False)
    cipher = encrypt(plain)
    cookie_manager = CookieManager(base_url, cipher)
    cookie = cookie_manager.get_cookie()
    if cookie:
        DEFAULT_CONFIG["cookie"]=cookie
        DEFAULT_CONFIG["base_url"]=base_url
        print(f":配置详情{DEFAULT_CONFIG}")

    return DEFAULT_CONFIG


from src.function.upload import upload_for_one_directory
from src.cookie.config import get_config
from src.function.get_result import get_result
from src.function.seprate import separate_series_by_patient

#文件上传功能测试
# print(upload_for_one_directory(r"C:\Users\13167\Desktop\data\shuzhangqi\dcm",get_config(),"1"))

# #文件拆分：

# print(separate_series_by_patient(r"C:\Users\13167\Desktop\data"))
#
# #结果查询
# #"study_uid": "1.2.826.0.1.3680043.2.109.5.20220519102622656.1699758078.1",\n  "SeriesInstanceUID": "1.3.12.2.1107.5.1.4.73336.30000022051900071431600051249"

# print(get_result("1.2.826.0.1.3680043.2.109.5.20220519102622656.1699758078.1"))

#
async def Analysis_dicom_directory_tool(directory_path: str, series_type: str):
    return upload_for_one_directory(directory_path, get_config(), series_type)

async def separate_series_by_patient_tool(directory_path: str):
    return separate_series_by_patient(directory_path)

async def get_result_tool(study_uid: str):
    return get_result(study_uid)
       #, separate_series_by_patient_tool, get_result_tool)